Recent changes (master)

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



The following changes since commit 41ee2319ffef9a38fff09d9c80dd997929fb51e4:

  Merge branch 'filestat3' of https://github.com/kusumi/fio (2020-03-02 09:34:38 -0700)

are available in the Git repository at:

  git://git.kernel.dk/fio.git master

for you to fetch changes up to 8324e5d5ffbe87080eebec1cd0c3c8a0751257de:

  Merge branch 'patch-1' of https://github.com/felixonmars/fio (2020-03-03 08:11:08 -0700)

----------------------------------------------------------------
Felix Yan (1):
      Correct multiple typos in engines/libhdfs.c

Jens Axboe (1):
      Merge branch 'patch-1' of https://github.com/felixonmars/fio

 engines/libhdfs.c | 14 +++++++-------
 1 file changed, 7 insertions(+), 7 deletions(-)

---

Diff of recent changes:

diff --git a/engines/libhdfs.c b/engines/libhdfs.c
index 60001601..c57fcea6 100644
--- a/engines/libhdfs.c
+++ b/engines/libhdfs.c
@@ -2,7 +2,7 @@
  * libhdfs engine
  *
  * this engine helps perform read/write operations on hdfs cluster using
- * libhdfs. hdfs doesnot support modification of data once file is created.
+ * libhdfs. hdfs does not support modification of data once file is created.
  *
  * so to mimic that create many files of small size (e.g 256k), and this
  * engine select a file based on the offset generated by fio.
@@ -75,7 +75,7 @@ static struct fio_option options[] = {
 		.type	= FIO_OPT_STR_STORE,
 		.off1   = offsetof(struct hdfsio_options, directory),
 		.def    = "/",
-		.help	= "The HDFS directory where fio will create chuncks",
+		.help	= "The HDFS directory where fio will create chunks",
 		.category = FIO_OPT_C_ENGINE,
 		.group	= FIO_OPT_G_HDFS,
 	},
@@ -86,7 +86,7 @@ static struct fio_option options[] = {
 		.type	= FIO_OPT_INT,
 		.off1	= offsetof(struct hdfsio_options, chunck_size),
 		.def    = "1048576",
-		.help	= "Size of individual chunck",
+		.help	= "Size of individual chunk",
 		.category = FIO_OPT_C_ENGINE,
 		.group	= FIO_OPT_G_HDFS,
 	},
@@ -177,7 +177,7 @@ static enum fio_q_status fio_hdfsio_queue(struct thread_data *td,
 	
 	if( (io_u->ddir == DDIR_READ || io_u->ddir == DDIR_WRITE) && 
 	     hdfsTell(hd->fs, hd->fp) != offset && hdfsSeek(hd->fs, hd->fp, offset) != 0 ) {
-		log_err("hdfs: seek failed: %s, are you doing random write smaller than chunck size ?\n", strerror(errno));
+		log_err("hdfs: seek failed: %s, are you doing random write smaller than chunk size ?\n", strerror(errno));
 		io_u->error = errno;
 		return FIO_Q_COMPLETED;
 	};
@@ -338,9 +338,9 @@ static int fio_hdfsio_setup(struct thread_data *td)
 		}
 		f->real_file_size = file_size;
 	}
 	/* If the size doesn't divide nicely with the chunck size,
 	 * make the last files bigger.
-	 * Used only if filesize was not explicitely given
+	 * Used only if filesize was not explicitly given
 	 */
 	if (!td->o.file_size_low && total_file_size < td->o.size) {
 		f->real_file_size += (td->o.size - total_file_size);
@@ -374,7 +374,7 @@ static int fio_hdfsio_io_u_init(struct thread_data *td, struct io_u *io_u)
 	}
 	hd->fs = hdfsBuilderConnect(bld);
 	
-	/* hdfsSetWorkingDirectory succeed on non existend directory */
+	/* hdfsSetWorkingDirectory succeed on non-existent directory */
 	if (hdfsExists(hd->fs, options->directory) < 0 || hdfsSetWorkingDirectory(hd->fs, options->directory) < 0) {
 		failure = errno;
 		log_err("hdfs: invalid working directory %s: %s\n", options->directory, strerror(errno));
@@ -338,9 +338,9 @@ static int fio_hdfsio_setup(struct thread_data *td)
 		f->real_file_size = file_size;
 	}
-	/* If the size doesn't divide nicely with the chunck size,
+	/* If the size doesn't divide nicely with the chunk size,
 	 * make the last files bigger.



[Index of Archives]     [Linux Kernel]     [Linux SCSI]     [Linux IDE]     [Linux USB Devel]     [Video for Linux]     [Linux Audio Users]     [Yosemite News]     [Linux SCSI]

  Powered by Linux